@@ -56,7 +56,7 @@ behaviour.
 # Note: Some functions are implicitly provided by imports in the generated
 #       virtualenv bootstrap script (e.g. sys, os, os.path.join, logger, and
 #       call_process).
-from os.path import exists
+from os.path import exists, abspath
 
 #---  Third-party imports
 
@@ -459,7 +459,7 @@ def _install_distribution(installer_cmd, installer_opts, distribution_specs):
     # a shell.  In fact quoting specifiers breaks the code under Linux.  This
     # needs to be verified on Windows, however.
     full_install_cmd = (
-      [join(bin_dir, installer_cmd)] +
+      [abspath(join(bin_dir, installer_cmd))] +
       installer_opts.split() +
       distribution_specs)
     call_subprocess(full_install_cmd)
